@@ -1,6 +1,6 @@
 import os
-from misc import execution_path
-from logging import my_logging
+from .misc import execution_path
+from .logging import my_logging
 
 class _Config(object):
     """
@@ -17,7 +17,7 @@ class _Config(object):
             e.g. 'plt' for matplotlib.pyplot, 'scipy' for scipy.interpolate. and whose values
             are Boolean
         
-        - Datafile: a dictionary holding the HI atom, which can be used intensively in Atom.getIonicAbundance
+        - Datafile: a dictionary holding the HI atom, which can be used intensively in Atom.getIonAbundance
         
         - pypic_path: This is only set when needed (basically by getEmisGridDict).
             The default value for the pypic_path parameter of getEmisGridDict().
@@ -54,8 +54,27 @@ class _Config(object):
             self.Nprocs = 1
         if 'XUVTOP' in os.environ:
             self.INSTALLED['Chianti'] = True
+            try:
+                xuvtop = os.environ['XUVTOP']
+                vFileName = os.path.join(xuvtop, 'VERSION')
+                vFile = open(vFileName)
+                versionStr = vFile.readline()
+                vFile.close()
+                self.Chianti_version = versionStr.strip()
+                self.Chianti_version_main = self.Chianti_version.split('.')[0]
+            except:
+                self.Chianti_version = None
+                self.Chianti_version_main = None
         else:
             self.INSTALLED['Chianti'] = False
+            self.Chianti_version = None
+            self.Chianti_version_main = None
+        if 'STOUT_DIR' in os.environ:
+            self.INSTALLED['Stout'] = True
+            self.Stout_dir = os.environ['STOUT_DIR']
+        else:
+            self.INSTALLED['Stout'] = False
+            self.Stout_dir = None
         try:
             import pyfits
             self.INSTALLED['pyfits'] = True
@@ -67,6 +86,16 @@ class _Config(object):
                 self.INSTALLED['pyfits from astropy'] = True
             except:
                 self.INSTALLED['pyfits from astropy'] = False
+        try:
+            import h5py
+            self.INSTALLED['h5py'] = True
+        except:
+            self.INSTALLED['h5py'] = False
+        try:
+            import cvxopt
+            self.INSTALLED['cvxopt'] = True
+        except:
+            self.INSTALLED['cvxopt'] = False
         
         self.DataFiles = {}
             
@@ -147,5 +176,4 @@ class _Config(object):
     
     def unuse_multiprocs(self):
         self._use_mp = False    
-        
-    
\ No newline at end of file
+            
\ No newline at end of file
